@@ -6,6 +6,7 @@ module Test.QuickCheck.Instances.Transformer () where
 import Prelude ()
 import Prelude.Compat
 
+import Control.Monad.Trans.Maybe (MaybeT(..))
 import Data.Functor.Sum (Sum (..))
 
 import Test.QuickCheck
@@ -16,6 +17,14 @@ import Test.QuickCheck
 
 -- TODO: CoArbitrary and Function, needs Coarbitrary1 and Function1
 
+instance (Arbitrary1 m) => Arbitrary1 (MaybeT m) where
+  liftArbitrary = fmap MaybeT . liftArbitrary . liftArbitrary
+  liftShrink shr (MaybeT m) = map MaybeT (liftShrink (liftShrink shr) m)
+
+instance (Arbitrary1 m, Arbitrary a) => Arbitrary (MaybeT m a) where
+  arbitrary = arbitrary1
+  shrink = shrink1
+
 instance (Arbitrary1 f, Arbitrary1 g) => Arbitrary1 (Sum f g) where
   liftArbitrary arb = oneof [fmap InL (liftArbitrary arb), fmap InR (liftArbitrary arb)]
   liftShrink shr (InL f) = map InL (liftShrink shr f)
